@@ -14,16 +14,18 @@ except ImportError:  # pragma: no cover
 from akro.box import Box
 from akro.dict import Dict
 from akro.discrete import Discrete
+from akro.image import Image
 from akro.space import Space
 from akro.tuple import Tuple
 
 
-def from_gym(space):
-    """
-    Convert a gym.space to an akro.space.
+def from_gym(space, is_image=False):
+    """Convert a gym.space to an akro.space.
 
     Args:
         space(:obj:`gym.Space`): The Space object to convert.
+        is_image(boolean): True if input is an image, False otherwise.
+            This is False by default.
 
     Returns:
         akro.Space: The gym.Space object converted to an
@@ -31,6 +33,10 @@ def from_gym(space):
 
     """
     if isinstance(space, gym.spaces.Box):
+        if is_image:
+            assert (space.low == 0).all() and (space.high == 255).all(), \
+                'Low and high values must be 0 and 255 for an Image'
+            return Image(space.shape)
         return Box(low=space.low, high=space.high)
     elif isinstance(space, gym.spaces.Dict):
         return Dict(space.spaces)
@@ -43,5 +49,6 @@ def from_gym(space):
 
 
 __all__ = [
-    'Space', 'Box', 'Dict', 'Discrete', 'Tuple', 'from_gym', 'tf', 'theano'
+    'Space', 'Box', 'Dict', 'Discrete', 'Image', 'Tuple', 'from_gym', 'tf',
+    'theano'
 ]
